/* This file is part of QGoogleTranslate
 *
 * Copyright (C) 2009 Durachenko Alexei V. <lexnewton86@gmail.com>
 */

#include "ceditorwidget.h"
#include "config.h"
#include <QScriptEngine>
#include <QScriptValueIterator>

void simpleResponceParcer( QString& text );

CEditorWidget::CEditorWidget( QWidget * parent, Qt::WFlags f)
	: QWidget(parent, f)
{
	setupUi(this);
	for( int i = 0; i < gGoogleLangCount; ++i )
	{
	    comboBox_LangSrc->addItem( gGoogleLang[i].name );
	    comboBox_LangDest->addItem( gGoogleLang[i].name );

        QString path = QString(":/flags/flags/none.png");
        QString flag = QString(":/flags/flags/%1.png").arg( gGoogleLang[i].code );
        if( QFile::exists( flag ) )
        {
            path = flag;
        }
        comboBox_LangSrc->setItemIcon( i, QIcon( path ) );
        comboBox_LangDest->setItemIcon( i, QIcon( path ) );
	}

    m_Buffer = 0;

	m_Http = new QHttp( this );
	connect( m_Http, SIGNAL( done( bool ) ), SLOT( slot_http_done( bool ) ) );
    connect( plainTextEdit_Input, SIGNAL( textChanged() ), SLOT( slot_plainTextEdit_Input_textChanged() ) );
}


CEditorWidget::~CEditorWidget()
{
    if( m_Buffer )
    {
        delete m_Buffer;
    }
}

void CEditorWidget::setSourceText( const QString& text )
{
    plainTextEdit_Input->clear();
    plainTextEdit_Input->insertPlainText( text );
}


void CEditorWidget::translate()
{
    on_pushButton_TranslateIt_clicked();
}


void CEditorWidget::setTabWidget( QTabWidget* tabWidget )
{
    m_TabWidget = tabWidget;
}


void CEditorWidget::setSourceLanguageIndex( int index )
{
    if( index < 0 || index > gGoogleLangCount ) index = 0;
    comboBox_LangSrc->setCurrentIndex( index );
}


void CEditorWidget::setDestinationLanguageIndex( int index )
{
    if( index < 0 || index > gGoogleLangCount ) index = 0;
    comboBox_LangDest->setCurrentIndex( index );
}


void CEditorWidget::slot_plainTextEdit_Input_textChanged()
{
    QString text = plainTextEdit_Input->toPlainText();

    if( text.isEmpty() )
    {
        pushButton_TranslateIt->setEnabled( false );
        m_TabWidget->setTabIcon( m_TabWidget->currentIndex(), QIcon(":/icons/icons/empty.png") );
    } else {
        pushButton_TranslateIt->setEnabled( true );
        m_TabWidget->setTabIcon( m_TabWidget->currentIndex(), QIcon(":/icons/icons/edited.png") );
    }

    text.replace( '\n', "" );
    text.replace( '\r', "" );

    if( text.length() > 10 ) text = text.left( 10 ) + QString( "..." );

    m_TabWidget->setTabText( m_TabWidget->currentIndex(), text );
}


void CEditorWidget::setBlocking( bool state )
{
    state = ! state;
    setEnabled( state );
}


void CEditorWidget::slot_http_done( bool error )
{
    setBlocking( false );
    if( error == false )
    {
        QString text = QString::fromUtf8( m_Http->readAll() );
        plainTextEdit_Output->clear();

        simpleResponceParcer( text );

        plainTextEdit_Output->insertPlainText( text );

        m_TabWidget->setTabIcon( m_TabWidget->currentIndex(), QIcon(":/icons/icons/ok.png") );
    } else {
        plainTextEdit_Output->clear();
        plainTextEdit_Output->insertPlainText( tr("HTTP ERROR: ") );
        plainTextEdit_Output->insertPlainText( m_Http->errorString() );
        m_TabWidget->setTabIcon( m_TabWidget->currentIndex(), QIcon(":/icons/icons/error.png") );
    }
}


void CEditorWidget::on_pushButton_TranslateIt_clicked()
{
    m_Http->abort();

    QSettings settings( QSettings::IniFormat, QSettings::UserScope, gProjectFamily, gProjectName );

    if( settings.value( "UseProxyServer", false ).toBool() == true )
    {
        QNetworkProxy proxy;
        proxy.setType( static_cast<QNetworkProxy::ProxyType>( settings.value( "ProxyType" ).toInt() ) );
        proxy.setHostName( settings.value( "ProxyHost", "" ).toString() );
        proxy.setPort( settings.value( "ProxyPort", 80 ).toInt() );
        proxy.setUser( settings.value( "ProxyUser", "" ).toString() );
        proxy.setPassword( settings.value( "ProxyPassword", "" ).toString() );
        m_Http->setProxy( proxy );
    } 
    else
    {
        m_Http->setProxy( QNetworkProxy( QNetworkProxy::NoProxy ) );    
    }

    QString text = QString::fromUtf8(QUrl::toPercentEncoding( plainTextEdit_Input->toPlainText() ));

    QString url = QString("/translate_a/t?client=t&sl="
                       +  QString( gGoogleLang[comboBox_LangSrc->currentIndex()].code )
                       + "&tl="
                       + QString( gGoogleLang[comboBox_LangDest->currentIndex()].code ) );

    QHttpRequestHeader header = QHttpRequestHeader("POST", url, 1, 1);
    header.setValue("Host", "www.google.com");
    header.setValue("User-Agent", "Mozilla/5.0");
    header.setValue("Accept-Encoding", "deflate");
    header.setContentLength( text.length() );
    header.setValue("Connection", "Close");

    QByteArray ba("text=");
    ba.append( text );

    m_Http->setHost("www.google.com");
    m_Http->request(header,ba);

    setBlocking( true );
}


void CEditorWidget::on_toolButton_SwapLang_clicked()
{
	int srcLangIndex = comboBox_LangSrc->currentIndex();
	int destLangIndex = comboBox_LangDest->currentIndex();
	comboBox_LangSrc->setCurrentIndex( destLangIndex );
	comboBox_LangDest->setCurrentIndex( srcLangIndex );
}


void simpleResponceParcer( QString& text )
{
    //qDebug() << text;
    QScriptEngine script;
    QScriptValue values = script.evaluate( text );

    text = QString();
    if( values.property(0).isObject() )
    {
        for( int row = 0; values.property(0).property(row).isArray(); ++row )
        {
            //qDebug() << values.property(0).property(row).toString();
            text += values.property(0).property(row).property(0).toString();
        }
    }
    
    // -- old code -- ( build 6 )
    //text = QString();
    //for( int i = 0; values.property( "sentences" ).property( i ).isObject(); ++i )
    //{
    //    text += values.property( "sentences" ).property( i ).property( "trans" ).toString();
    //    text += QString( " " );
    //}
}
